﻿namespace JSLintNet.VisualStudio.Errors
{
    using System.Text.RegularExpressions;
    using JSLintNet.Models;
    using JSLintNet.VisualStudio.Properties;
    using Microsoft.VisualStudio.Shell;
    using Microsoft.VisualStudio.Shell.Interop;
    using Microsoft.VisualStudio.Text.Adornments;
    using Microsoft.VisualStudio.Text.Tagging;

    /// <summary>
    /// A task that handles JSLint errors.
    /// </summary>
    internal class JSLintErrorTask : ErrorTask, IErrorTag
    {
        private static readonly Regex WordBoundaryPattern = new Regex(@"[^\$\w]", RegexOptions.Compiled);

        /// <summary>
        /// Initializes a new instance of the <see cref="JSLintErrorTask" /> class.
        /// </summary>
        /// <param name="document">The document.</param>
        /// <param name="jsLintError">The JSLint error.</param>
        /// <param name="category">The category.</param>
        /// <param name="hierarchy">The hierarchy.</param>
        public JSLintErrorTask(string document, IJSLintError jsLintError, TaskErrorCategory category, IVsHierarchy hierarchy)
        {
            this.Document = document;
            this.Category = TaskCategory.BuildCompile;
            this.ErrorCategory = category;
            this.Line = jsLintError.Line - 1;
            this.Column = jsLintError.Character - 1;
            this.Text = GetText(jsLintError);
            this.HierarchyItem = hierarchy;
        }

        /// <summary>
        /// Gets the type of error to use.
        /// </summary>
        /// <returns>The type of error to use.</returns>
        public string ErrorType
        {
            get
            {
                return PredefinedErrorTypeNames.CompilerError;
            }
        }

        /// <summary>
        /// Gets the content to use when displaying a tooltip for this error.
        /// </summary>
        /// <returns>The content to use when displaying a tooltip for this error.</returns>
        public object ToolTipContent
        {
            get
            {
                return this.Text;
            }
        }

        /// <summary>
        /// Gets a text representation of the specified error.
        /// </summary>
        /// <param name="error">The error.</param>
        /// <returns>
        /// A text representation of the error.
        /// </returns>
        private static string GetText(IJSLintError error)
        {
            return string.Concat(Resources.ErrorTaskPrefix, error.Reason);
        }
    }
}
