﻿namespace JSLintNet.Console.Specifications
{
    using System;
    using System.Linq;
    using JSLintNet.Console.Abstractions;
    using JSLintNet.QualityTools;
    using Moq;
    using Xunit;

    public class ConsoleWriterUnit
    {
        public class Write : UnitBase
        {
            [Fact]
            public void Should_split_text_into_lines()
            {
                using (var testable = new WriteTestable())
                {
                    testable.Instance.Write("This is quite a long sentence with some words and spaces, just one comma and a full stop at the end. This is quite a long sentence with some words and spaces, just one comma and a full stop at the end. This is quite a long sentence with some words and spaces, just one comma and a full stop at the end. This is quite a long sentence with some words and spaces, just one comma and a full stop at the end. This is quite a long sentence with some words and spaces, just one comma and a full stop at the end.");

                    var lines = testable.LastWrite.Split(new string[] { Environment.NewLine }, StringSplitOptions.None);

                    Assert.True(lines.All(x => x.Length <= 80));
                }
            }

            [Fact]
            public void Should_split_text_into_lines_with_indentation()
            {
                using (var testable = new WriteTestable())
                {
                    testable.Instance.Write(8, "This is quite a long sentence with some words and spaces, just one comma and a full stop at the end. This is quite a long sentence with some words and spaces, just one comma and a full stop at the end. This is quite a long sentence with some words and spaces, just one comma and a full stop at the end. This is quite a long sentence with some words and spaces, just one comma and a full stop at the end. This is quite a long sentence with some words and spaces, just one comma and a full stop at the end.");

                    var lines = testable.LastWrite.Split(new string[] { Environment.NewLine }, StringSplitOptions.None);

                    Assert.True(lines.All(x => x.Length <= 80));
                    Assert.True(lines.All(x => x.StartsWith("        ")));
                }
            }

            [Fact]
            public void Should_escape_format_characters()
            {
                using (var testable = new WriteTestable())
                {
                    testable.Instance.Write("{0} {1}", "format", "error with {braces}");

                    Assert.Equal("format error with {{braces}}", testable.LastWrite);
                }
            }

            [Fact]
            public void Should_throw_given_too_long_indentation()
            {
                using (var testable = new WriteTestable())
                {
                    Assert.Throws<ArgumentException>(() =>
                    {
                        testable.Instance.Write(41, string.Empty);
                    });
                }
            }

            private class WriteTestable : ConsoleWriterTestableBase
            {
            }
        }

        private abstract class ConsoleWriterTestableBase : TestableBase<ConsoleWriter>
        {
            public ConsoleWriterTestableBase()
            {
                this.ConsoleWrapperMock = this.AutoMocker.Mock<IConsoleWrapper>();
                this.BufferWidth = 80;

                this.BeforeInit += this.OnBeforeInit;
            }

            public int BufferWidth { get; set; }

            public string LastWrite { get; set; }

            public Mock<IConsoleWrapper> ConsoleWrapperMock { get; set; }

            private void OnBeforeInit(object sender, EventArgs e)
            {
                this.ConsoleWrapperMock
                    .SetupGet(x => x.BufferWidth)
                    .Returns(() => this.BufferWidth);

                this.ConsoleWrapperMock
                    .Setup(x => x.Write(It.IsAny<string>(), It.IsAny<object[]>()))
                    .Callback((string x, object[] y) => this.LastWrite = x);
            }
        }
    }
}
