﻿namespace JSLintNet.Console.Specifications
{
    using System;
    using System.IO;
    using JSLintNet.QualityTools;
    using JSLintNet.QualityTools.Helpers;
    using Xunit;

    public class ProgramIntegration : IntegrationBase
    {
        private static readonly string ProgramPath = new Uri(typeof(Program).Assembly.CodeBase).LocalPath;

        private static readonly string ScriptsRoot = Path.GetFullPath(Path.Combine(Environment.CurrentDirectory, @"..\..\Resources\Scripts"));

        [Fact]
        public void Should_find_errors_in_source_directory()
        {
            var result = ProcessHelper.Execute(ProgramPath, @"""" + ScriptsRoot + @"""");

            Assert.True(result.ExitCode > 0);
        }

        [Fact]
        public void Should_stop_when_error_limit_reached()
        {
            var args = @"""" + ScriptsRoot + @""" /l """"Verbose"""" /s """ + ScriptsRoot + @"\Limits.json""";
            var result = ProcessHelper.Execute(ProgramPath, args);

            Expect.GreaterThan(100, result.ExitCode);
            Expect.LessThan(150, result.ExitCode);
            Assert.Contains("Total JSLint error limit reached:", result.Error);
        }
    }
}
