﻿namespace JSLintNet.QualityTools.Helpers
{
    using System.Text.RegularExpressions;
    using Xunit.Sdk;

    public static class Expect
    {
        public static void Matches(string pattern, string actual)
        {
            Matches(new Regex(pattern), actual);
        }

        public static void Matches(string pattern, RegexOptions options, string actual)
        {
            Matches(new Regex(pattern, options), actual);
        }

        public static void Matches(Regex pattern, string actual)
        {
            if (!pattern.IsMatch(actual))
            {
                throw new AssertException("Expected \"" + actual + "\" to match pattern \"" + pattern.ToString() + "\"");
            }
        }

        public static void StartsWith(string value, string actual)
        {
            if (!actual.StartsWith(value))
            {
                throw new AssertException("Expected \"" + actual + "\" to start with \"" + value + "\"");
            }
        }

        public static void EndsWith(string value, string actual)
        {
            if (!actual.EndsWith(value))
            {
                throw new AssertException("Expected \"" + actual + "\" to end with \"" + value + "\"");
            }
        }

        public static void GreaterThan(int expected, int actual)
        {
            if (!(actual > expected))
            {
                throw new AssertException("Expected \"" + actual + "\" to be greater than \"" + expected + "\"");
            }
        }

        public static void LessThan(int expected, int actual)
        {
            if (!(actual < expected))
            {
                throw new AssertException("Expected \"" + actual + "\" to be less than \"" + expected + "\"");
            }
        }
    }
}
