﻿namespace JSLintNet.Specifications
{
    using JSLintNet.QualityTools;
    using JSLintNet.QualityTools.Helpers;
    using Xunit;

    public class JSLintNetSettingsUnit
    {
        public class NormalizeIgnore : UnitBase
        {
            [Fact]
            public void Should_replace_forward_slashes_with_back_slashes()
            {
                using (var testable = new NormalizeIgnoreTestable())
                {
                    var ignore = testable.Instance.Ignore;
                    ignore.Add(@"some/path");
                    ignore.Add(@"/some/other/path");
                    ignore.Add(@"other/path");

                    var actual = testable.Instance.NormalizeIgnore();

                    Assert.Contains(@"some\path", actual[0]);
                    Assert.Contains(@"\some\other\path", actual[1]);
                    Assert.Contains(@"other\path", actual[2]);
                }
            }

            [Fact]
            public void Should_add_directory_separator_prefix_where_absent()
            {
                using (var testable = new NormalizeIgnoreTestable())
                {
                    var ignore = testable.Instance.Ignore;
                    ignore.Add(@"some\path");
                    ignore.Add(@"\some\other\path");
                    ignore.Add(@"other\path");

                    var actual = testable.Instance.NormalizeIgnore();

                    Expect.StartsWith(@"\", actual[0]);
                    Expect.StartsWith(@"\", actual[2]);
                }
            }

            [Fact]
            public void Should_not_add_directory_separator_suffix_to_js_file()
            {
                using (var testable = new NormalizeIgnoreTestable())
                {
                    var ignore = testable.Instance.Ignore;
                    ignore.Add(@"path\to\file.js");

                    var actual = testable.Instance.NormalizeIgnore();

                    Assert.Equal(@"\path\to\file.js", actual[0]);
                }
            }

            [Fact]
            public void Should_not_add_directory_separator_suffix_to_json_file()
            {
                using (var testable = new NormalizeIgnoreTestable())
                {
                    var ignore = testable.Instance.Ignore;
                    ignore.Add(@"root\data.json");

                    var actual = testable.Instance.NormalizeIgnore();

                    Assert.Equal(@"\root\data.json", actual[0]);
                }
            }

            [Fact]
            public void Should_add_directory_separator_suffix_where_absent()
            {
                using (var testable = new NormalizeIgnoreTestable())
                {
                    var ignore = testable.Instance.Ignore;
                    ignore.Add(@"path\to");
                    ignore.Add(@"another\path\");
                    ignore.Add(@"looks/like/a.file");

                    var actual = testable.Instance.NormalizeIgnore();

                    Expect.EndsWith(@"\", actual[0]);
                    Expect.EndsWith(@"\", actual[2]);
                }
            }

            private class NormalizeIgnoreTestable : JSLintNetSettingsTestableBase
            {
            }
        }

        private abstract class JSLintNetSettingsTestableBase : TestableBase<JSLintNetSettings>
        {
        }
    }
}
