﻿namespace JSLintNet.VisualStudio.Specifications.EventControllers
{
    using System;
    using EnvDTE;
    using EnvDTE80;
    using JSLintNet.QualityTools;
    using JSLintNet.VisualStudio.Errors;
    using JSLintNet.VisualStudio.EventControllers;
    using Moq;

    internal abstract class EventControllerTestableBase<T> : TestableBase<T>
        where T : EventControllerBase
    {
        public EventControllerTestableBase()
        {
            this.ServiceProviderMock = this.AutoMocker.Mock<IServiceProvider>();
            this.ErrorListProviderMock = this.AutoMocker.Mock<IJSLintErrorListProvider>();
            this.VisualStudioJSLintProviderMock = this.AutoMocker.Mock<IVisualStudioJSLintProvider>();

            this.EnvironmentMock = new Mock<DTE2>();
            this.EventsMock = new Mock<Events>();

            this.BeforeInit += this.OnBeforeInit;

            this.AfterInit += this.OnAfterInit;
        }

        public Mock<IServiceProvider> ServiceProviderMock { get; set; }

        public Mock<DTE2> EnvironmentMock { get; set; }

        public Mock<Events> EventsMock { get; set; }

        internal Mock<IJSLintErrorListProvider> ErrorListProviderMock { get; set; }

        internal Mock<IVisualStudioJSLintProvider> VisualStudioJSLintProviderMock { get; set; }

        private void OnBeforeInit(object sender, EventArgs e)
        {
            this.ServiceProviderMock
                .Setup(x => x.GetService(typeof(DTE)))
                .Returns(this.EnvironmentMock.Object);

            this.EnvironmentMock
                .SetupGet(x => x.Events)
                .Returns(this.EventsMock.Object);
        }

        private void OnAfterInit(object sender, EventArgs e)
        {
            this.Instance.Initialize();
        }
    }
}
